@@ -1,9 +1,8 @@
 package Test::Code::TidyAll::Plugin::JSHint;
 
-use File::Slurp::Tiny qw(write_file);
 use Test::Class::Most parent => 'Test::Code::TidyAll::Plugin';
 
-sub test_filename { 'foo.js' }
+sub test_filename {'foo.js'}
 
 sub _extra_path {
     'node_modules/.bin';
@@ -44,12 +43,12 @@ sub test_main : Tests {
     $self->tidyall(
         source       => 'while (day)\n  shuffle();',
         conf         => { options => 'camelcase curly' },
-        expect_error => qr/Expected \'{/,
+        expect_error => qr/Expected \'\{/,
         desc         => 'error - curly - options=camelcase,curly',
     );
 
-    my $rc_file = $self->{root_dir} . "/jshint.json";
-    write_file( $rc_file, '{"camelcase": true}' );
+    my $rc_file = $self->{root_dir}->child('jshint.json');
+    $rc_file->spew('{"camelcase": true}');
 
     $self->tidyall(
         source       => 'var my_object = {};',
